.. image:: https://img.shields.io/pypi/v/jaraco.envs.svg
   :target: https://pypi.org/project/jaraco.envs

.. image:: https://img.shields.io/pypi/pyversions/jaraco.envs.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.envs/master.svg
   :target: https://travis-ci.org/jaraco/jaraco.envs

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black
   :alt: Code style: Black

.. .. image:: https://img.shields.io/appveyor/ci/jaraco/jaraco-envs/master.svg
..    :target: https://ci.appveyor.com/project/jaraco/jaraco-envs/branch/master

.. .. image:: https://readthedocs.org/projects/jaracoenvs/badge/?version=latest
..    :target: https://jaracoenvs.readthedocs.io/en/latest/?badge=latest

Classes for orchestrating Python (virtual) environments.
